@@ -8,7 +8,7 @@ use base qw/File::Assets::Filter/;
 use Digest;
 use File::Assets;
 
-for my $ii (qw/content_digest content_digester/) {
+for my $ii (qw/fingerprint_digest fingerprint_digester/) {
     no strict 'refs';
     *$ii = sub {
         my $self = shift;
@@ -26,9 +26,8 @@ my %default = (qw/
         skip_if_exists 0
         skip_inline 1
         check_content 0
-        content_digest 0
+        fingerprint_digest 1
         check_age 1 
-        check_digest 1
     /,
 );
 
@@ -39,8 +38,6 @@ sub new {
     while (my ($setting, $value) = each %default) {
         $self->cfg->{$setting} = exists $_{$setting} ? $_{$setting} : $value;
     }
-    $self->cfg->{content_digest} = 1 if $self->cfg->{check_content};
-    # TODO Set content_digest if output_path is 1?
     return $self;
 }
 
@@ -50,8 +47,8 @@ sub pre {
 
     return 0 if $self->skip_if_exists;
 
-    if ($self->cfg->{content_digest}) {
-        $self->content_digester(File::Assets::Util->digest);
+    if ($self->cfg->{fingerprint_digest}) {
+        $self->fingerprint_digester(File::Assets::Util->digest);
     }
 
     return 1;
@@ -60,9 +57,9 @@ sub pre {
 sub process {
     my $self = shift;
     $self->SUPER::process(@_);
-    if (my $digester = $self->content_digester) {
-        my $asset = shift;
-        $digester->add($asset->content_digest."\n");
+    if (my $digester = $self->fingerprint_digester) {
+        my $asset = $_[0];
+        $digester->add($asset->digest."\n");
     }
 }
 
@@ -76,18 +73,15 @@ sub post {
 
     return if $self->cfg->{skip_single} && 1 == @$matched;
 
-    if (my $digester = $self->content_digester) {
-        $self->content_digest($digester->hexdigest);
+    if (my $digester = $self->fingerprint_digester) {
+        $self->fingerprint_digest($digester->hexdigest);
     }
 
-#    my $type = $self->find_type;
-
     return if $self->skip_if_exists;
 
     my $build = $self->should_build;
 
     if ($build) {
-        $self->check_digest_file->touch;
         $self->build;
     }
 
@@ -109,28 +103,28 @@ sub skip_if_exists {
 sub should_build {
     my $self = shift;
 
-    if ($self->cfg->{check_content}) {
-        my $digest = $self->content_digest;
-        my $dir = $self->group->rsc->dir->subdir(".check-content-digest");
-        my $file = $dir->file($digest);
-        unless (-e $file) {
-            $file->touch;
-            return 1;
-        }
-        $file->touch;
-    }
+#    if ($self->cfg->{check_content}) {
+#        my $digest = $self->fingerprint_digest;
+#        my $dir = $self->group->rsc->dir->subdir(".check-content-digest");
+#        my $file = $dir->file($digest);
+#        unless (-e $file) {
+#            $file->touch;
+#            return 1;
+#        }
+#        $file->touch;
+#    }
 
     if ($self->cfg->{check_age}) {
         my $mtime = $self->mtime;
-        return 1 if $mtime > $self->output_asset->mtime;
+        return 1 if $mtime > $self->output_asset->file_mtime;
     }
 
-    if ($self->cfg->{check_digest}) {
-        my $file = $self->check_digest_file;
-        unless (-e $file) {
-            return 1;
-        }
-    }
+#    if ($self->cfg->{check_digest}) {
+#        my $file = $self->check_digest_file;
+#        unless (-e $file) {
+#            return 1;
+#        }
+#    }
 
     return 0;
 }
@@ -140,36 +134,18 @@ sub match {
     my $asset = shift;
     my $match = shift;
     return $self->SUPER::match($asset, $match &&
-        (! $asset->inline || ! $self->cfg->{skip_inline}));
+        (! $asset->inline || ! $self->cfg->{skip_inline}) &&
+        (! $asset->outside)
+    );
 }
 
-sub check_digest_file {
-    my $self = shift;
-    my $digest = $self->digest;
-    my $dir = $self->assets->rsc->dir->subdir(".check-digest");
-    $dir->mkpath unless -d $dir;
-    my $file = $dir->file($digest);
-    return $file;
-}
-
-#sub asset {
+#sub check_digest_file {
 #    my $self = shift;
-#    return $self->stash->{asset} ||= do {
-#        my $type = shift || $self->find_type;
-#        my $path = File::Assets::Util->build_asset_path(undef, # $output
-#            assets => $self->assets,
-#            filter => $self,
-#            name => $self->assets->name,
-#            type => $type,
-#            digest => $self->digest,
-#            content_digest => $self->content_digest,
-#        );
-#        return File::Assets::Util->parse_asset_by_path(
-#            path => $path,
-#            base => $self->assets->rsc,
-#            type => $type,
-#        );
-#    }
+#    my $key_digest = $self->key_digest;
+#    my $dir = $self->assets->rsc->dir->subdir(".check-digest");
+#    $dir->mkpath unless -d $dir;
+#    my $file = $dir->file($key_digest);
+#    return $file;
 #}
 
 sub build {
@@ -206,22 +182,21 @@ sub substitute {
     }
 
     splice @$slice, $top_match->{rank}, 0, $asset; 
-
-#    my $matched = $self->matched;
-#    for my $match (@$matched) {
-#        $match->{asset}->hide;
-#    }
-#
-#    $self->bucket->add_asset($asset);
 }
 
+sub fingerprint {
+    return $_[0]->fingerprint_digest;
+}
+
+1;
+
+__END__
+
 sub find_type {
     my $self = shift;
     my $frob;
     return $frob if $frob = $self->type;
-    # FIXME Is this a good idea? What happens when you mix types?
     return $frob if (($frob = $self->matched->[0]) && ($frob = $frob->{asset}->type));
     return undef;
 }
 
-1;
